shared

package
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 26, 2019 License: Apache-2.0 Imports: 0 Imported by: 0

Documentation

Index

Constants

const (
	// InformationMessage is the hint for informational messages.
	InformationMessage = "INFO"
	// WarningMessage is the hint for warning messages.
	WarningMessage = "WARN"
	// CriticalMessage is the hint for critical level messages.
	CriticalMessage = "CRIT"
	// DebugMessage is the hint for debug level messages.
	DebugMessage = "DEBUG"
)

Variables

This section is empty.

Functions

func AuditSender

func AuditSender(msg string, pipe chan string)

AuditSender is not able to drop messages, it will therefore slow down your application in order to ship logs. This can have undesirable effects on your application, however if logs are more important than service then this is the only option.

func BestEffortSender

func BestEffortSender(msg string, pipe chan string, droppedFunc func())

BestEffortSender will send messages to the printer until the buffer is full. Once the buffer is full messages will spill and be dropped. Each message dropped will in increase the dropped message counter. This is mode is useful when you decide that service is more important than log shipping. Most time users will want this option even though they may not have thought much about it. It is therefore the default option.

Types

This section is empty.

Jump to